## Description

_Provide a concise description of the change. Explain what this PR does and why it's needed._

_If applicable, describe any visual/UI changes or link to screenshots._

This pull request is categorized as a:

- [ ] New feature
- [ ] Bug fix
- [ ] Code refactor
- [ ] Documentation
- [ ] Other

## Related Issue(s)

_Reference any related issues. Use keywords like Fixes, Closes, or Resolves._

- Fixes: #  
- Related: #

## Checklist

- [ ] I have removed any unrelated changes from this PR
- [ ] I’ve run `just test-all` and ensured all tests pass
- [ ] I’ve run `just typecheck` and resolved any typing issues
- [ ] I’ve run `just format` to auto-format code

If any new functionality was added or changed, were tests included?

- [ ] Yes, tests were added/updated
- [ ] No, and I understand this will likely delay review/merge
- [ ] N/A

## Platform/Environment Tested

- [ ] Linux/macOS
- [ ] Dev Container (VSCode)
- [ ] Other:

## Notes for Reviewers

_Optional: Add anything important for the reviewer to know like edge cases, decisions made, etc._

_Note: Keep changes focused. If unrelated improvements or issues are discovered, consider opening a separate PR to maintain clarity and reviewability._

## Final Notes

Consider adding an uplifting comment like "I hope you do your best to make today an outstanding day!" or adding an image of a cute frog/snek.